import { ref } from "vue-demi";
import { RecaptchaContextKey, normalizeOptions } from "./composables/context.mjs";
import { createRecaptchaProxy } from "./composables/proxy.mjs";
import { checkRecaptchaLoad, recaptchaLoaded } from "./script-manager/common.mjs";
import { warn } from "./utils.mjs";
import { createHeadRecaptcha } from "./script-manager/head.mjs";
export function createPlugin(plugins = []) {
  const { getRecaptcha, scriptLoader } = Object.assign(
    {
      scriptLoader: createHeadRecaptcha,
      getRecaptcha: () => window.grecaptcha
    },
    ...plugins
  );
  return {
    install(app, options) {
      const isReady = ref(false);
      async function waitLoaded() {
        await recaptchaLoaded.promise;
        isReady.value = true;
      }
      waitLoaded().catch((error) => warn("fail to load reCAPTCHA script", error));
      checkRecaptchaLoad();
      const opt = normalizeOptions(options);
      app.provide(RecaptchaContextKey, {
        isReady,
        scriptInjected: false,
        proxy: createRecaptchaProxy(isReady, getRecaptcha),
        useScriptProvider: scriptLoader(opt.loaderOptions),
        options: opt
      });
    }
  };
}
